@@ -14,5 +14,6 @@ if __name__ == '__main__':
 
     # threadpool(pin,yum).run(1)
     # threadpool(pin,firewalld).run(1)
-    threadpool(pin,hostname).run(3)
+    # threadpool(pin,hostname).run(3)
+    # threadpool(pin,dns).run(3)
 
